#!/usr/bin/env perl

# Load module and libraries
use strict;
use IO::File;
use POSIX qw(setsid);
#require "../usr/lib/Agent_Core_Functions.pl";

# Initialize variable
my $quit = 0;
my $timeout = 0;
my $lastTaskTest;
my $pidfile = $ARGV[0];
my $postrun = "False";
my $postscript = "postmortem.sh";

# signal handler
$SIG{TERM} = $SIG{INT} = sub { $quit++;  };

# Become a daemon
my $fh = open_pid_file($pidfile);
my $pid = become_daemon();
print $fh $pid;
close $fh;

open(LOGDAEMON,">>../log/service_log.txt");
log_msg("Service started");
# Check if manager service ip and cert are supplied dynamically
my $rungugentcmd = get_run_gugent_cmd();
# Run as a daemon
while(!$quit)
{
    # Run the agent here
    #$lastTaskTest = Run_Agent("GetWorkItem");
    chdir "/usr/share/gugent";
    system($rungugentcmd);

    if (!$quit)
    {
        # Disable the service
        # Try RedHat/SUSE:
        if (system("chkconfig --del vrm-agent") != 0) {
            # If that fails, try Debian:
            system("update-rc.d -f vrm-agent remove");
        }
        unlink("/etc/init.d/vrm-agent");
        # The way to diable an updstart service is to add the .override
        # file, but in this case the Guest Agent will not be started again.
        unlink("/etc/init/vrm-agent.conf");

        # Log service uninstall
        open(FILE,">>../log/service_installation.txt");
        print FILE "Service has been removed\n";
        close(FILE);
        $quit++;
    }

    # Wait for 45 secs to be sure the machine is booted
    sleep(45);

    if (-e $postscript)
    {
        $postrun = $postscript;
    }
    else
    {
        # Set the reboot command
        $postrun='reboot';
    }
}

print LOGDAEMON "Postmortem script: $postrun\n";

# Log service stopped
log_msg("Service stopped");
close(LOGDAEMON);

# Test if a reboot is required
if ($postrun ne "False")
{
    `$postrun`;
}

sub get_run_gugent_cmd{
    return "./rungugent.sh";
}

# function to become daemon
sub become_daemon{
    die "can't fork" unless defined (my $child = fork);
    #Parent dies
    exit 0 if $child;
    #Become session leader
    setsid();
    open(STDIN, "</dev/null");
    open(STDOUT, ">/dev/null");
    open(STDERR, ">&STDOUT");
    # Forget file creation mask
    umask(0);
    return $$;
}

# function to open the pid file
sub open_pid_file{
    my $file = shift;
    if (-e $file)
    {
        my $fh = IO::File->new($file) || return;
        my $pid = <$fh>;
        warn "Removing PID file for defunct agent process $pid.\n";
        die "Can't unlink PID file $file" unless -w $file && unlink $file;
    }
    return IO::File->new($file,O_WRONLY|O_CREAT|O_EXCL,0644) or die "Can't create $file: $!\n";
}

sub log_msg{
    my $msg = shift;
    my $time = localtime;
    print LOGDAEMON "$time: $msg\n"
}

END{ unlink $pidfile if $$ == $pid; log_msg("Service stopped"); close(LOGDAEMON); }
