#!/bin/bash

[ x$GUGENT_INSTALL_PATH = x"" ] && GUGENT_INSTALL_PATH=/usr/share/gugent
[ x$GUGENT_RUN_PROPERTIES = x"" ] && GUGENT_RUN_PROPERTIES=$GUGENT_INSTALL_PATH/rungugent.properties

[ x$GUGENT_BINARY_PATH = x"" ] && GUGENT_BINARY_PATH=/usr/bin

[ x$GUGENT_SSL_OPTION = x"" ] && GUGENT_SSL_OPTION="True"
[ x$GUGENT_NO_UMASK = x"" ] && GUGENT_NO_UMASK="False"
[ x$GUGENT_EC2_INSTANCE = x"" ] && GUGENT_EC2_INSTANCE="False"
[ x$GUGENT_VCD_MACHINE = x"" ] && GUGENT_VCD_MACHINE="False"
[ x$GUGENT_VCA_MACHINE = x"" ] && GUGENT_VCA_MACHINE="False"

if [ $# -gt 0 ]; then
    manager_service_host_port=$1
    shift
else
    echo $"Usage: $0 manager-service-host:port [ssl] [noumask] [ec2|vcd|vca|vsphere]"
fi

while [ $# -gt 0 ]; do
    case "$1" in
        ssl)
            GUGENT_SSL_OPTION="True"
            shift
            ;;
        nossl)
            GUGENT_SSL_OPTION="False"
            shift
            ;;
        noumask)
             GUGENT_NO_UMASK="True"
             shift
             ;;
        ec2)
             GUGENT_EC2_INSTANCE="True"
             GUGENT_VCD_MACHINE="False"
             GUGENT_VCA_MACHINE="False"
             shift
             ;;
        vca)
             GUGENT_VCA_MACHINE="True"
             GUGENT_EC2_INSTANCE="False"
             GUGENT_VCD_MACHINE="False"
             shift
             ;;
        vcd)
             GUGENT_VCD_MACHINE="True"
             GUGENT_EC2_INSTANCE="False"
             GUGENT_VCA_MACHINE="False"
             shift
             ;;
        vsphere)
             GUGENT_VCD_MACHINE="False"
             GUGENT_EC2_INSTANCE="False"
             GUGENT_VCA_MACHINE="False"
             shift
             ;;
        *)
            echo $"Usage: $0 manager-service-host:port [ssl] [noumask] [ec2|vcd|vsphere]"
            exit 1
    esac
done

if [ ! -x $GUGENT_BINARY_PATH/gugent ]; then
    echo "Gugent binary not found at $GUGENT_BINARY_PATH/gugent"
    exit 1
fi

if [ ! -d $GUGENT_INSTALL_PATH ]; then
    echo "Gugent install directory not found at $GUGENT_INSTALL_PATH"
    exit 1
fi

chmod a+x $GUGENT_BINARY_PATH/gugent

chmod a+x $GUGENT_INSTALL_PATH/vrm-agent
chmod a+x $GUGENT_INSTALL_PATH/vrm-agentd
chmod a+x $GUGENT_INSTALL_PATH/VRM_daemon.pl
chmod a+x $GUGENT_INSTALL_PATH/rungugent.sh
chmod a+x $GUGENT_INSTALL_PATH/postmortem.sh

echo host_port_property="$manager_service_host_port" > $GUGENT_RUN_PROPERTIES
echo ssl_option_property="$GUGENT_SSL_OPTION" >> $GUGENT_RUN_PROPERTIES
echo ec2_instance_property="$GUGENT_EC2_INSTANCE" >> $GUGENT_RUN_PROPERTIES
echo vcd_customize_property="$GUGENT_VCD_MACHINE" >> $GUGENT_RUN_PROPERTIES
echo vca_customize_property="$GUGENT_VCA_MACHINE" >> $GUGENT_RUN_PROPERTIES
echo extra_arguments_property="" >> $GUGENT_RUN_PROPERTIES

if [ "$GUGENT_NO_UMASK" = "True" ]; then
    sed -i -e 's/umask/#umask/g' $GUGENT_INSTALL_PATH/VRM_daemon.pl
fi

cp $GUGENT_INSTALL_PATH/vrm-agent /etc/init.d

mkdir -p /usr/share/log

type chkconfig > /dev/null 2>&1
if [ $? -eq 0 ]; then
    chkconfig --add vrm-agent
else
    type upstart-socket-bridge > /dev/null 2>&1
    if [ $? -eq 0 ]; then
        rm -f $GUGENT_INSTALL_PATH/vrm-agent
        rm -f $GUGENT_INSTALL_PATH/vrm-agentd
        cp $GUGENT_INSTALL_PATH/vrm-agent.conf /etc/init
    else
        type update-rc.d > /dev/null 2>&1
        if [ $? -eq 0 ]; then
            /usr/sbin/update-rc.d vrm-agent defaults
        else
            echo "Unable to install boot script.  update-rc.d and chkconfig not found"
            exit 1
        fi
    fi
fi

exit 0
