#!/bin/bash

[ x$GUGENT_INSTALL_PATH = x"" ] && GUGENT_INSTALL_PATH=/usr/share/gugent
[ x$GUGENT_RUN_PROPERTIES = x"" ] && GUGENT_RUN_PROPERTIES=$GUGENT_INSTALL_PATH/rungugent.properties

[ x$GUGENT_BINARY_PATH = x"" ] && GUGENT_BINARY_PATH=/usr/bin

[ x$GUGENT_EC2_WGET_STDOUT_OPTIONS = x"" ] && GUGENT_EC2_WGET_STDOUT_OPTIONS="--timeout=60 --tries=5 --wait=10 -q -O -"
[ x$GUGENT_VMWARE_TOOLS_LOCATIONS = x"" ] && GUGENT_VMWARE_TOOLS_LOCATIONS=/etc/vmware-tools/locations

[ x$GUGENT_WAIT_INTERVAL = x"" ] && GUGENT_WAIT_INTERVAL=30
[ x$GUGENT_WAIT_LIMIT = x"" ] && GUGENT_WAIT_LIMIT=600

[ x$GUGENT_QUIESCE_DELAY = x"" ] && GUGENT_QUIESCE_DELAY=0

ec2_metadata_latest_url=http://169.254.169.254/latest
wait_counter=0

export AXIS2C_HOME=axis2
export LD_LIBRARY_PATH=axis2/lib
export PYTHONPATH=$GUGENT_INSTALL_PATH/site/dops

if [ ! -x $GUGENT_BINARY_PATH/gugent ]; then
    echo "Gugent binary not found at $GUGENT_BINARY_PATH/gugent"
    exit 1
fi

if [ ! -d $GUGENT_INSTALL_PATH ]; then
    echo "Gugent install directory not found at $GUGENT_INSTALL_PATH"
    exit 1
fi

if [ ! -f $GUGENT_RUN_PROPERTIES ]; then
    echo "$GUGENT_RUN_PROPERTIES not found."
    exit 1
fi

# The following properties are read from $GUGENT_RUN_PROPERTIES
# host_port_property
# ssl_option_property
# ec2_instance_property
# vca_customize_property
# vcd_customize_property
# extra_arguments_property

. $GUGENT_RUN_PROPERTIES

# Optionally override the host address property
if [ -n "$1" ]; then
    host_port_property=$1
fi

echo_d()
{
    CURDATE=`date`
    echo -e $CURDATE "$*"
    echo -e $CURDATE "$*" >> $GUGENT_INSTALL_PATH/GuestAgent.log
}

function VMWAREtoolsDaemonPath()
{
    ret=0
    sbin_path=
    if [ -f $GUGENT_VMWARE_TOOLS_LOCATIONS ]; then
        sbin_path=`grep '^answer[ \\t]* SBINDIR' $GUGENT_VMWARE_TOOLS_LOCATIONS | tail -1 | awk '{print $3}'`
    fi

    command="/usr/bin/vmtoolsd"
    if [ -n "$sbin_path" ]; then
        if [ -d $sbin_path ]; then
            command="$sbin_path/vmtoolsd"
        fi
    fi

    if [ ! -f $command ]; then
        command="/usr/bin/vmware-guestd"
        if [ -n "$sbin_path" ]; then
            if [ -d $sbin_path ]; then
                command="$sbin_path/vmware-guestd"
            fi
        fi
    fi

    if [ ! -f $command ]; then
        echo_d "VMware Tools daemon cannot be found"
        ret=1
    elif [ ! -x $command ]; then
        echo_d "VMware Tools daemon not executable"
        ret=1
    fi

    return $ret
}

function VMWAREtoolsGuestCustomizationStatus()
{
    gc_status=`$1 --cmd "info-get guestinfo.gc.status"`
    return $?
}

function VMWAREtoolsGuestInfoVrmServerHost()
{
    vrm_host=`$1 --cmd "info-get guestinfo.Vrm.Server.Host"`
    return $?
}

function VMWAREtoolsWaitForGuestCustomization()
{

    echo_d "Waiting for VMware guest customization to complete..."

    if ! VMWAREtoolsDaemonPath; then
        return 1
    fi

    wait_counter=0
    started_gc=False
    completed_gc=False

    echo_d "Waiting for VMware guest customization to start..."

    while [ x"$started_gc" = x"False" ]
    do

        if (( wait_counter > GUGENT_WAIT_LIMIT )); then
            echo_d "Wait limit $GUGENT_WAIT_LIMIT seconds is over."
            return 1
        fi

        if ! VMWAREtoolsGuestCustomizationStatus $command; then
            echo_d "VMware Tools status check unexpectedly failed: $gc_status"
            return 1
        fi
        if [ x"$gc_status" = x"Started" ]; then
            started_gc=True
        elif [ x"$gc_status" = x"Successful" ]; then
            started_gc=True
        else
            echo_d "Unexpected guest customization status: $gc_status"
        fi

        ((wait_counter+=GUGENT_WAIT_INTERVAL))
        echo_d "WAIT_COUNTER is $wait_counter, GUGENT_WAIT_LIMIT is $GUGENT_WAIT_LIMIT, sleep $GUGENT_WAIT_INTERVAL"
        sleep $GUGENT_WAIT_INTERVAL

    done

    echo_d "Waiting for VMware guest customization to start...done."

    wait_counter=0

    echo_d "Waiting for VMware guest customization to complete..."

    while [ x"$completed_gc" = x"False" ]
    do

        if (( wait_counter > GUGENT_WAIT_LIMIT )); then
            echo_d "Wait limit $GUGENT_WAIT_LIMIT seconds is over."
            return 1
        fi

        if ! VMWAREtoolsGuestCustomizationStatus $command; then
            echo_d "VMware Tools status check unexpectedly failed: $gc_status"
            return 1
        fi

        if [ x"$gc_status" = x"Successful" ]; then
            completed_gc=True
        elif [ x"$gc_status" != x"Started" ]; then
            echo_d "Unexpected guest customization status: $gc_status"
        fi

        ((wait_counter+=GUGENT_WAIT_INTERVAL))
        echo_d "WAIT_COUNTER is $wait_counter, GUGENT_WAIT_LIMIT is $GUGENT_WAIT_LIMIT, sleep $GUGENT_WAIT_INTERVAL"
        sleep $GUGENT_WAIT_INTERVAL

    done

    echo_d "Waiting for VMware guest customization to complete...done."

    return 0

}


function VMWAREtoolsWaitForGuestInfoVrmServerHost()
{

    echo_d "Waiting for VMware guestinfo to complete..."

    if ! VMWAREtoolsDaemonPath; then
        return 1
    fi

    wait_counter=0
    started_gi=False

    echo_d "Waiting for VMware guestinfo..."

    while [ x"$started_gi" = x"False" ]
    do

        if (( wait_counter > GUGENT_WAIT_LIMIT )); then
            echo_d "Wait limit $GUGENT_WAIT_LIMIT seconds is over."
            return 1
        fi

        VMWAREtoolsGuestInfoVrmServerHost $command

        if [ x"$vrm_host" = x ]; then
            started_gi=False
        else
            started_gi=True
        fi

        ((wait_counter+=GUGENT_WAIT_INTERVAL))
        echo_d "WAIT_COUNTER is $wait_counter, GUGENT_WAIT_LIMIT is $GUGENT_WAIT_LIMIT, sleep $GUGENT_WAIT_INTERVAL"
        sleep $GUGENT_WAIT_INTERVAL

    done

    echo_d "Waiting for VMware guestinfo to complete ...done."

    return 0

}


#
# This loop requires the presence of the EC2 metadata server
# before continuing.  The metadata server is a link local address
# and cannot be blocked by EC2 networking features.
#
# When and if the user-data portion is present, this will indicate
# the meta-data server is ready.
#
function EC2waitForMetadata()
{
    echo_d "Waiting for the EC2 metadata server..."

    wget $GUGENT_EC2_WGET_STDOUT_OPTIONS $ec2_metadata_latest_url > /dev/null
    ret=$?
    while [ $ret -ne 0 ]; do
        wget $GUGENT_EC2_WGET_STDOUT_OPTIONS $ec2_metadata_latest_url > /dev/null
        ret=$?
        if [ $ret -ne 0 ]; then
            echo_d "WAIT_COUNTER is $wait_counter, GUGENT_WAIT_LIMIT is $GUGENT_WAIT_LIMIT, sleep $GUGENT_WAIT_INTERVAL"
            sleep $GUGENT_WAIT_INTERVAL;
        fi
        ((wait_counter+=GUGENT_WAIT_INTERVAL))
        if (( wait_counter > GUGENT_WAIT_LIMIT )); then
            echo_d "Wait limit $GUGENT_WAIT_LIMIT seconds is over."
            return 1
        fi
    done

    echo_d "Waiting for the EC2 metadata server...done."

    return 0
}

function EC2getInstanceName() {
    if ! EC2waitForMetadata; then
        return 1
    fi
    instance_name=`wget -q -O - $ec2_metadata_latest_url/meta-data/instance-id`
}

function quiesceInitialStartup()
{
    quiesce_counter=0

    echo_d "Countdown to Guest Agent startup..."

    while [ $quiesce_counter -lt $GUGENT_QUIESCE_DELAY ]
    do

        ((quiesce_counter+=GUGENT_WAIT_INTERVAL))
        echo_d "QUIESCE_COUNTER is $quiesce_counter, GUGENT_QUIESCE_DELAY is $GUGENT_QUIESCE_DELAY, sleep $GUGENT_WAIT_INTERVAL"
        sleep $GUGENT_WAIT_INTERVAL

    done

    echo_d "Countdown to Guest Agent startup...done."

    return 0
}

if [ "$ec2_instance_property" = "True" ]; then
    if ! EC2getInstanceName; then
        echo_d "EC2 instance name lookup failed"
        exit 1
    fi
    GUGENT_EXTRA_ARGS="--name=$instance_name $GUGENT_EXTRA_ARGS"
elif [ "$vcd_customize_property" = "True" ]; then
    if ! VMWAREtoolsWaitForGuestCustomization; then
        exit 1
    fi
elif [ "$vca_customize_property" = "True" ]; then
    if ! VMWAREtoolsWaitForGuestCustomization; then
        exit 1
    fi
else
# vsphere is the default from installguguent.sh
#
# If the "host_port_property" contains an improper
# host:port contents this situation signals a last ditch and
# insecure configuration could be attempted.  An improper
# host:port pair is defined as one without a colon ":"
#
    if [[ ! $host_port_property =~ : ]] ; then
        if ! VMWAREtoolsWaitForGuestInfoVrmServerHost; then
            exit 1
        fi
        host_port_property=$vrm_host:443
        ssl_option_property="True"
        cd $GUGENT_INSTALL_PATH
        echo | eval LD_LIBRARY_PATH=$GUGENT_INSTALL_PATH/lib $GUGENT_INSTALL_PATH/openssl s_client -connect $host_port_property 2> /dev/null | sed -ne '/BEGIN CERTIFICATE/,/END CERTIFICATE/p' > $GUGENT_INSTALL_PATH/cert.pem
        ./installgugent.sh $vrm_host:443 ssl vsphere
    fi
fi

ssl_option=""
if [ "$ssl_option_property" = "True" ]; then
    ssl_option="--ssl"
    cd $GUGENT_INSTALL_PATH
    LD_LIBRARY_PATH=$GUGENT_INSTALL_PATH/lib $GUGENT_INSTALL_PATH/openssl x509 -in $GUGENT_INSTALL_PATH/cert.pem -noout -fingerprint 2> /dev/null | grep Fingerprint
    ret=$?
    if [ $ret -ne 0 ]; then
        echo_d "Corrupted or invalid $GUGENT_INSTALL_PATH/cert.pem"
        exit 1
    fi
fi

quiesceInitialStartup

cd $GUGENT_INSTALL_PATH
while true; do
    $GUGENT_BINARY_PATH/gugent --host=$host_port_property $ssl_option --config=$GUGENT_INSTALL_PATH/gugent.properties --script=$GUGENT_INSTALL_PATH/site $GUGENT_EXTRA_ARGS $extra_arguments_property
    rc=$?
    if [ $rc -eq 255 ]; then
        break
    fi
    sleep $GUGENT_WAIT_INTERVAL
done
